<?php
/**
 * Plugin Name: Supplier Order Email
 * Plugin URI: https://mci-desarrollo.es/supplier-order-email-premium
 * Author: MCI Desarrollo
 * Version: 1.5.8
 * Author URI: https://mci-desarrollo.es
 * Text Domain: supplier-order-email
 * Description: Sends an automatic order emails to the suppliers to send the corresponding products to the customer. The mail is sent when the order goes to the "Processing" status.
 * Creates a new taxonomy (Suppliers) and a new selection box for each product.
 **/
//=======================================================================
//=======================================================================

// Exit if accessed directly  // Evita que se pueda acceder al archivo directamente
if (!defined('ABSPATH')) {
    exit;
}
/////////////////// Defines current versión number as constant  // Define el número de versión actual como una constante

if (!defined('MCISOE_VERSION')) {
    define('MCISOE_VERSION', '1.5.8');
}
/////////////////////////////////////////////////////////////////////////

// Load the textdomain
load_plugin_textdomain('supplier-order-email', false, basename(dirname(__FILE__)) . '/languages');

// Link to the style sheet  //Enlaza con la hoja de estilos
function mcisoe_enqueue_options_style()
{
    wp_enqueue_style('mcisoe', plugins_url('css/mcisoe_style.css', __FILE__));
}

add_action('admin_enqueue_scripts', 'mcisoe_enqueue_options_style');

//=================================================================
//Includes install / uninstall functions
require_once 'includes/install-mcisoe.php';

//=================================================================

//=======================================================================
// CREATE NEW TAXONOMY: SUPPLIER  // CREAR NUEVA TAXONOMIA: PROVEEDOR
//=======================================================================

add_action('init', 'mcisoe_new_taxonomy_suppliers');

function mcisoe_new_taxonomy_suppliers()
{
    $labels = array(
        'name'                       => 'Suppliers',
        'singular_name'              => 'Supplier',
        'menu_name'                  => 'Suppliers',
        'all_items'                  => 'All Suppliers',
        'parent_item'                => 'Parent Supplier',
        'parent_item_colon'          => 'Parent Suppliers:',
        'new_item_name'              => 'Name of new Supplier',
        'add_new_item'               => 'New Supplier',
        'edit_item'                  => 'Edit Supplier',
        'update_item'                => 'Update Supplier',
        'separate_items_with_commas' => 'Separate Item with commas',
        'search_items'               => 'Search Suppliers',
        'add_or_remove_items'        => 'Add or remove Suppliers',
        'choose_from_most_used'      => 'Choose from the most used Suppliers',
    );

    $args = array(
        'labels'            => $labels,
        'hierarchical'      => true,
        'rewrite'           => ['slug' => 'supplier', 'with_front' => false],
        'public'            => true,
        'show_ui'           => true,
        'show_admin_column' => true,
        'show_in_nav_menus' => true,
        'show_tagcloud'     => true,
    );

    register_taxonomy('supplier', 'product', $args);
    register_taxonomy_for_object_type('supplier', 'product');
}

// Agrega nuevo item al menu de administracion del escritorio
// Crea submenú y página de configuración del plugin

add_action("admin_menu", "mcisoe_item_woocommerce_menu");

function mcisoe_item_woocommerce_menu()
{
    add_submenu_page('woocommerce',
        'Supplier Order Email', // Page title
        __('Supplier Order Email', 'supplier-order-email'), // Menu title
        'manage_categories', // permissions
        'supplier-order-email', // slug
        'mcisoe_configuration_panel', // function that contains the configuration code
        75// position
    );
}

//=================================================================

// Plugin configuration function  // Función configuración del plugin
function mcisoe_configuration_panel()
{
    // Label of plugin name  // Etiqueta de nombre del plugin
    echo '<div class="supplier-order-email-title">';
    echo '<h2>';
    esc_html_e('SUPPLIER ORDER EMAIL', 'supplier-order-email');
    echo '</h2>';
    echo '</div>';

// Includes for the form  // Incluye el formulario

    require 'includes/get-form-mcisoe.php';
    require 'includes/form-mcisoe.php';

} // End config panel: mcisoe_configuration_panel

//=======================================================================
// Includes check premium
require_once 'includes/check_premium_mci.php';
require_once 'includes/old_auth_mci.php';

add_action('admin_init', 'mci_check_premium_in_api');

function mci_check_premium_in_api()
{
    if (!defined('MCI_API_KEY')) {
        define('MCI_API_KEY', 'oxAuRZ1WUqhGIYiQLjfTkSCgPlte43ND');
    }
    if (!defined('MCI_PLUGIN_SLUG')) {
        define('MCI_PLUGIN_SLUG', 'supplier-order-email');
    }

    $check_premium = new MciCheckPremium;
    $mci_old_auth  = new MciOldAuth;

    //Execute checking if urls are admin.php?page=plugin_slug or plugins.php
    global $pagenow;
    if (
        (($pagenow == 'admin.php') && ($_GET['page'] == MCI_PLUGIN_SLUG)) ||
        ($pagenow == 'plugins.php')
    ) {
        //Execute convert_pay_to_users if button is pressed
        if (isset($_POST['submit']) && isset($_POST['code_key']) && strlen($_POST['code_key']) > 18 &&
            !empty($_POST['code_key']) && isset($_POST['email']) && !empty($_POST['email'])) {

            $check_premium->convert_pay_to_user();
        }

        //Execute always if pages are admin.php?page=plugin_slug or plugins.php to deactivate $mcisoe_auth_premium if not autorized
        if ($check_premium->mci_verify() !== '1') {
            update_option('mcisoe_auth_premium', null);
        }

    }
    //Put this method back inside the $pagenow conditions  //Volver a meter este método dentro de las condiciones $pagenow
    //Run Mci_old_auth
    $mci_old_auth->create_user_from_old();
}

//=======================================================================

// Add notice messages  // Añade mensajes de aviso

function mcisoe_admin_notice_suppliers_wp()
{
// Check if the Supliers exists in Wordpress and display notice message if not exists // Comprobar si existen proveedores en Wordpress y mostrar mensaje de aviso si no los hay
    $terms = get_terms(array('taxonomy' => 'supplier', 'hide_empty' => false));
    $count = count($terms);

    $current_screen = get_current_screen();
    $current_screen = $current_screen->id;

    if (empty($count) && $current_screen != 'edit-supplier') {
        echo '<br><div class="notice notice-warning"><br>';
        echo __("Before you start using the 'Supplier Order Email' plugin <b> you must create the Suppliers in WooCommerce. </b> ", "supplier-order-email");

        echo '<a class="btn button" href="edit-tags.php?taxonomy=supplier"> ';
        echo __('CREATE SUPPLIERS IN WOOCOMMERCE NOW', 'supplier-order-email');

        echo '</a>';
        echo '<br><br></div><br>';
    }

    // Check if the Supliers exists in the Plugin and display notice message if not exists // Comprobar si existen proveedores en el plugin y mostrar mensaje de aviso si no los hay
    global $wpdb;
    $tabla_mcisoe_suppliers = sanitize_text_field($wpdb->prefix) . 'mcisoe_suppliers';
    $get_supplier_data      = $wpdb->get_results("SELECT id, supplier_name, supplier_email FROM " . esc_sql($tabla_mcisoe_suppliers) . " WHERE supplier_name != ''");

    $countsuppliers = count($get_supplier_data);

    $current_screen2 = get_current_screen();
    $current_screen2 = $current_screen2->id;

    if (!$countsuppliers && $current_screen2 != 'woocommerce_page_supplier-order-email') {
        echo '<div class="notice notice-warning"><br>';
        echo __("Before starting to use 'Supplier Order Email' <b> you must also add the Suppliers in the Plugin </b>. ", "supplier-order-email");
        echo '<br>';
        echo __("Write the 'Supplier name' exactly the same as in the Woocommerce supplier, respecting exactly upper and lower case. ", "supplier-order-email");

        echo '<a class="btn button" href="admin.php?page=supplier-order-email">';
        echo __('CREATE SUPPLIERS IN THE PLUGIN NOW', 'supplier-order-email');

        echo '</a>';
        echo '<br><br></div><br>';
    }
}
add_action('admin_notices', 'mcisoe_admin_notice_suppliers_wp');

//=======================================================================

// Instances the class and method execute  // Instancia la clase y ejecuta el método
require 'includes/email-mcisoe.php';
$sendemails = new McisoeSendEmails;
if (!isset($_GET['send_soe'])) { //If the send button has not been pressed manually in the order list. Si no se ha pulsado el botón de enviar manualmente en la lista de pedidos.
    $sendemails->mcisoe_send_email();
}

// Instances the class to be executed __construct  // Instancia la clase para que sea ejecutado __construct
require 'includes/email-admin-mcisoe.php';
$sendemailadmin = new McisoeSendEmailAdmin();

//========================================================================

add_action('admin_init', 'mcisoe_send_in_order_list');

function mcisoe_send_in_order_list()
{
    //  START Premium functionality /////////////////////////////////////////////////////////
    if (get_option('mcisoe_version') !== null) {
        require_once 'includes/get-db-mcisoe.php';
    }

    $mcisoe_auth_premium = get_option('mcisoe_auth_premium');

    if ($mcisoe_auth_premium) { // Check password premium

        //Button to manually send an the order to the supplier from the order list.
        //Botón para enviar manualmente el pedido al proveedor desde la lista de pedidos.
        add_filter('woocommerce_admin_order_actions', function ($actions, $order) {

            $order_id = $order->get_id();

            $actions['soe'] = array(
                //'url'    => '/wp-admin/edit.php?post_type=shop_order&send_soe=' . $order_id,
                'url'    => wp_nonce_url('/wp-admin/edit.php?post_type=shop_order&send_soe=' . $order_id, 'soe_nonce'),
                'name'   => __('Send order email to supplier manually', 'woocommerce'),
                'action' => 'soe',
            );

            if (isset($_GET['send_soe']) && $order_id == $_GET['send_soe']) {

                if (isset($_GET['_wpnonce'])) {
                    $verify_nonce = wp_verify_nonce($_GET['_wpnonce'], 'soe_nonce');
                } else {
                    $verify_nonce = false;
                }

                if ($verify_nonce != false) {
                    $sendemail = new McisoeSendEmails;
                    $send_ok   = $sendemail->trigger($_GET['send_soe']);
                    if ($send_ok) {
                        $sendEmailAdmin = new McisoeSendEmailAdmin;
                        $sendEmailAdmin->trigger($_GET['send_soe']);
                    }
                    wp_redirect('/wp-admin/edit.php?post_type=shop_order');
                }
            }
            return $actions;
        }, 10, 2);

        add_action('admin_head', function () {
            echo '<style>.wc-action-button-soe::after { font-family: woocommerce !important; content: "\2709" !important; font-size:23px; line-height: 21px!important;}</style>';
        });
    }
}
//  END Premium functionality /////////////////////////////////////////////////////////